yakumo.nova.v2.security_group_rule.Manager

Package yakumo :: Package nova :: Package v2 :: Module security_group_rule :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
     base.SubManager --+
                       |
                      Manager

Manager class for security group rules in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for security group rules in Compute API v2

Instance Methods | [hide private]
yakumo.base.Manager |
__init__(self, parent_resource, *args, **kwargs) Create a Manager object | source code
_reload_rules(self) | source code
yakumo.nova.v2.security_group_rule.Resource |
create(self, remote_ip_prefix=`'``__UNDEF__``'`, port_range_min=`'``__UNDEF__``'`, port_range_max=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, group=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) Create a security group rule | source code
yakumo.nova.v2.security_group_rule.Resource |
get(self, id) Get a security group rule | source code
_find_gen(self, **kwargs) Find a security group rule | source code
Inherited from `base.Manager`: `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``security_group_rule``'``
| _json_resources_key = ``'``security_group_rules``'``
| _url_resource_path = ``'``/os-security-group-rules``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, parent_resource, *args, **kwargs) (Constructor) | source code
Create a Manager object kwargs: options Parameters: `client` - client object `verbose` - Whether str(Resource) displays all attributes Returns: yakumo.base.Manager Manager object Overrides: object.__init__ (inherited documentation)

### create(self, remote_ip_prefix=`'``__UNDEF__``'`, port_range_min=`'``__UNDEF__``'`, port_range_max=`'``__UNDEF__``'`, protocol=`'``__UNDEF__``'`, group=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) | source code
Create a security group rule Parameters: `remote_ip_prefix` (str) - IP range (e.q. '0.0.0.0/0', required) `port_range_min` (int) - lower number of destination port `port_range_max` (int) - upper number of destination port `protocol` (str) - protocol name ('tcp', 'udp', or 'icmp') `group` ([(yakumo.project.Resource, str)]) - List of a project and a security group name `project` (yakumo.project.Resource) - Project Returns: yakumo.nova.v2.security_group_rule.Resource Created security group rule Overrides: base.Manager.create

### get(self, id) | source code
Get a security group rule Parameters: `id` (str) - Security group rule ID Returns: yakumo.nova.v2.security_group_rule.Resource Created security group rule Overrides: base.Manager.get

### _find_gen(self, **kwargs) | source code
Find a security group rule :param key=value: search condition Overrides: base.Manager._find_gen

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('remote_ip_prefix', 'ip_range', mapper.No
      op), ('port_range_min', 'from_port', mapper.Noop), ('port_range_max',
      'to_port', mapper.Noop), ('protocol', 'ip_protocol', mapper.Noop), ('g
      roup', 'group', mapper.Noop), ('project', 'tenant_id', mapper.Resource
      ('project')),]